import * as React from "react"
import { LoadingContext, LoadingContextProps } from "@/plugins/LoadingContext"

/**
 * Hook de React para acceder al contexto de carga.
 * Esto es útil para casos de uso como mostrar un indicador de carga en la interfaz de usuario.
 *
 * @returns {LoadingContextProps} El contexto de carga.
 * @throws {Error} Si se intenta usar fuera de un LoadingProvider.
 */
function useLoading (): LoadingContextProps {
  const loading = React.useContext(LoadingContext)

  if (!loading) {
    throw new Error("useLoading must be used within a LoadingProvider")
  }

  return loading
}

export default useLoading
