"use client"

import * as React from "react"
import dynamic from "next/dynamic"
import presets from "@/utils/globalPresets"

// @ts-ignore
const LoadingSpinner = dynamic(() => import("vComponents/dist/Loading"), { ssr: false })

/** ----------------------------------------------------------------------------------------------
 * LoadingContext
 * ----------------------------------------------------------------------------------------------- */

export interface LoadingContextProps {
  loading: boolean
  setLoading: (loading: boolean) => void
  start: () => void
  stop: () => void
}

export const LoadingContext = React.createContext<LoadingContextProps>({
  loading: false,
  setLoading: (loading: boolean) => {},
  start: () => {},
  stop: () => {}
})

/** ----------------------------------------------------------------------------------------------
 * LoadingProvider
 * ----------------------------------------------------------------------------------------------- */

interface LoadingProviderProps {
  children: React.ReactNode
}

const LoadingProvider = ({ children }: LoadingProviderProps) => {
  const [loading, setLoading] = React.useState<boolean>(false)

  const loadingWrapper = React.useMemo(() => ({
    loading,
    setLoading,
    start: () => setLoading(true),
    stop: () => setLoading(false)
  }), [loading])

  return (
    <LoadingContext.Provider value={loadingWrapper}>
      {children}
      {/* @ts-ignore */}
      <LoadingSpinner loading={loading} image={presets.images.imageLoader} background={"backgroundLoader"} color={"colorLoader"} />
    </LoadingContext.Provider>
  )
}

export default LoadingProvider
