'use client'

import * as React from "react"
import rosetta from "rosetta"
import { execute } from "@/helper/clientApi"
import useHasMounted from "@/hooks/useHasMounted"

const i18n = rosetta()
const defaultLanguage = "es"
const languages = ["es", "en"]
const contentLanguageMap = { es: "es-GT", en: "en-US" }
const I18nContext = React.createContext()

// default language
i18n.locale(defaultLanguage)

const I18nProvider = ({ children, locale, dict }) => {
  const activeLocaleRef = React.useRef(locale || defaultLanguage)
  const [, setTick] = React.useState(0)
  const firstRender = React.useRef(true)
  const [langIsLoaded, setLangIsLoaded] = React.useState(false)
  const hasMounted = useHasMounted()

  const i18nWrapper = {
    activeLocale: activeLocaleRef.current,
    langIsLoaded,
    t: (...args) => i18n.t(...args),
    locale: (l, dict) => {
      i18n.locale(l)
      activeLocaleRef.current = l
      if (dict) {
        i18n.set(l, dict)
      }
      // force rerender to update view
      setTick((tick) => tick + 1)
    }
  }

  const setLanguage = async () => {
    let msgs = {}
    locale = defaultLanguage
    // si la app ya esta renderizada se cargan los textos
    if (hasMounted) {
      const i18nDb = await execute("SPR_I18N_T", [locale])
      msgs = i18nDb?.reduce((obj, elm) => {
        obj[elm.id_mensaje_padre] = { ...obj[elm.id_mensaje_padre], [elm.id_mensaje]: elm.mensaje }
        return obj
      }, {})
    }
    i18nWrapper.locale(locale, msgs)
    setLangIsLoaded(true)
  }

  // for initial SSR render
  if (locale && firstRender.current === true) {
    firstRender.current = false
    setLanguage()
  }

  // when page is mounted
  React.useEffect(() => {
    if (hasMounted) {
      setLanguage()
    }
  }, [hasMounted, activeLocaleRef.current])

  return (
    <I18nContext.Provider value={i18nWrapper}>{children}</I18nContext.Provider>
  )
}

export { defaultLanguage, languages, contentLanguageMap, I18nContext }

export default I18nProvider
